@@ -1,13 +1,13 @@
 # This file is part of python-sql.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-import string
 import numbers
+import string
 import warnings
-from threading import local, currentThread
 from collections import defaultdict
 from itertools import chain
+from threading import current_thread, local
 
-__version__ = '1.3.0'
+__version__ = '1.4.0'
 __all__ = ['Flavor', 'Table', 'Values', 'Literal', 'Column', 'Join',
     'Asc', 'Desc', 'NullsFirst', 'NullsLast', 'format2numeric']
 
@@ -48,13 +48,16 @@ class Flavor(object):
         paramstyle - state the type of parameter marker formatting
         ilike - support ilike extension
         no_as - doesn't support AS keyword for column and table
+        no_boolean - doesn't support boolean type
         null_ordering - support NULL ordering
         function_mapping - dictionary with Function to replace
+        filter_ - support filter on aggregate functions
+        escape_empty - support empty escape
     '''
 
     def __init__(self, limitstyle='limit', max_limit=None, paramstyle='format',
             ilike=False, no_as=False, no_boolean=False, null_ordering=True,
-            function_mapping=None, filter_=False):
+            function_mapping=None, filter_=False, escape_empty=False):
         assert limitstyle in ['fetch', 'limit', 'rownum']
         self.limitstyle = limitstyle
         self.max_limit = max_limit
@@ -65,6 +68,7 @@ class Flavor(object):
         self.null_ordering = null_ordering
         self.function_mapping = function_mapping or {}
         self.filter_ = filter_
+        self.escape_empty = escape_empty
 
     @property
     def param(self):
@@ -76,7 +80,7 @@ class Flavor(object):
     @staticmethod
     def set(flavor):
         '''Set this thread's flavor to flavor.'''
-        currentThread().__sql_flavor__ = flavor
+        current_thread().__sql_flavor__ = flavor
 
     @staticmethod
     def get():
@@ -87,10 +91,10 @@ class Flavor(object):
         sets this thread's flavor.
         '''
         try:
-            return currentThread().__sql_flavor__
+            return current_thread().__sql_flavor__
         except AttributeError:
             flavor = Flavor()
-            currentThread().__sql_flavor__ = flavor
+            current_thread().__sql_flavor__ = flavor
             return flavor
 
 
@@ -500,8 +504,8 @@ class Select(FromItem, SelectQuery):
 
     @property
     def windows(self):
-        from sql.functions import WindowFunction
         from sql.aggregate import Aggregate
+        from sql.functions import WindowFunction
         windows = set()
         if self._windows is not None:
             for window in self._windows:
@@ -730,7 +734,9 @@ class Insert(WithQuery):
         columns = ''
         if self.columns:
             assert all(col.table == self.table for col in self.columns)
-            columns = ' (' + ', '.join(map(str, self.columns)) + ')'
+            # Get columns without alias
+            columns = ', '.join(c.column_name for c in self.columns)
+            columns = ' (' + columns + ')'
         with AliasManager():
             if isinstance(self.values, Query):
                 values = ' %s' % str(self.values)
@@ -793,7 +799,7 @@ class Update(Insert):
     def __str__(self):
         assert all(col.table == self.table for col in self.columns)
         # Get columns without alias
-        columns = list(map(str, self.columns))
+        columns = [c.column_name for c in self.columns]
 
         with AliasManager():
             from_ = ''
@@ -1338,14 +1344,18 @@ class Column(Expression):
     def name(self):
         return self._name
 
-    def __str__(self):
-        name = (self._name if self._name == '*'
+    @property
+    def column_name(self):
+        return (
+            self._name if self._name == '*'
             else _escape_identifier(self._name))
+
+    def __str__(self):
         alias = self._from.alias
         if alias:
-            return '%s.%s' % (_escape_identifier(alias), name)
+            return '%s.%s' % (_escape_identifier(alias), self.column_name)
         else:
-            return name
+            return self.column_name
 
     @property
     def params(self):
