@@ -1,39 +1,8 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2011-2018, Cédric Krier
-# Copyright (c) 2011-2018, B2CK
-# All rights reserved.
-#
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions are met:
-#     * Redistributions of source code must retain the above copyright
-#       notice, this list of conditions and the following disclaimer.
-#     * Redistributions in binary form must reproduce the above copyright
-#       notice, this list of conditions and the following disclaimer in the
-#       documentation and/or other materials provided with the distribution.
-#     * Neither the name of the <organization> nor the
-#       names of its contributors may be used to endorse or promote products
-#       derived from this software without specific prior written permission.
-#
-# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
-# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-# ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
-# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
-# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
-# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
-# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
+# This file is part of python-sql.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 from itertools import chain
 
-from sql import Expression, Flavor, FromItem, Window
-
-try:
-    basestring
-except NameError:
-    basestring = str
+from sql import CombiningQuery, Expression, Flavor, FromItem, Select, Window
 
 __all__ = ['Abs', 'Cbrt', 'Ceil', 'Degrees', 'Div', 'Exp', 'Floor', 'Ln',
     'Log', 'Mod', 'Pi', 'Power', 'Radians', 'Random', 'Round', 'SetSeed',
@@ -77,6 +46,8 @@ class Function(Expression, FromItem):
     def _format(value):
         if isinstance(value, Expression):
             return str(value)
+        elif isinstance(value, (Select, CombiningQuery)):
+            return '(%s)' % value
         else:
             return Flavor().get().param
 
@@ -94,7 +65,7 @@ class Function(Expression, FromItem):
             return Mapping(*self.args).params
         p = []
         for arg in self.args:
-            if isinstance(arg, Expression):
+            if isinstance(arg, (Expression, Select, CombiningQuery)):
                 p.extend(arg.params)
             else:
                 p.append(arg)
@@ -328,7 +299,7 @@ class Trim(Function):
         param = flavor.param
 
         def format(arg):
-            if isinstance(arg, basestring):
+            if isinstance(arg, str):
                 return param
             else:
                 return str(arg)
@@ -342,7 +313,7 @@ class Trim(Function):
             return Mapping(self.string, self.position, self.characters).params
         p = []
         for arg in (self.characters, self.string):
-            if isinstance(arg, basestring):
+            if isinstance(arg, str):
                 p.append(arg)
             elif hasattr(arg, 'params'):
                 p.extend(arg.params)
@@ -479,6 +450,8 @@ class AtTimeZone(Function):
             return str(Mapping(self.field, self.zone))
         if isinstance(self.zone, Expression):
             zone = str(self.zone)
+        elif isinstance(self.zone, (Select, CombiningQuery)):
+            zone = '(%s)' % self.zone
         else:
             zone = flavor.param
         return '%s AT TIME ZONE %s' % (str(self.field), zone)
@@ -488,7 +461,7 @@ class AtTimeZone(Function):
         Mapping = Flavor.get().function_mapping.get(self.__class__)
         if Mapping:
             return Mapping(self.field, self.zone).params
-        if isinstance(self.zone, Expression):
+        if isinstance(self.zone, (Expression, Select, CombiningQuery)):
             return self.field.params + self.zone.params
         else:
             return self.field.params + (self.zone,)
