@@ -1,40 +1,15 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2011-2013, Cédric Krier
-# Copyright (c) 2011-2013, B2CK
-# All rights reserved.
-#
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions are met:
-#     * Redistributions of source code must retain the above copyright
-#       notice, this list of conditions and the following disclaimer.
-#     * Redistributions in binary form must reproduce the above copyright
-#       notice, this list of conditions and the following disclaimer in the
-#       documentation and/or other materials provided with the distribution.
-#     * Neither the name of the <organization> nor the
-#       names of its contributors may be used to endorse or promote products
-#       derived from this software without specific prior written permission.
-#
-# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
-# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-# ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
-# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
-# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
-# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
-# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
+# This file is part of python-sql.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 import unittest
 import warnings
 from array import array
 
-from sql import Table, Literal, Null, Flavor
-from sql.operators import (And, Or, Not, Neg, Pos, Less, Greater, LessEqual,
-    GreaterEqual, Equal, NotEqual, Between, NotBetween, IsDistinct,
-    IsNotDistinct, Is, IsNot, Sub, Mul, Div, Mod, Pow, Abs, LShift, RShift,
-    Like, NotLike, ILike, NotILike, In, NotIn, FloorDiv, Exists)
+from sql import Flavor, Literal, Null, Table
+from sql.operators import (
+    Abs, And, Between, Div, Equal, Exists, FloorDiv, Greater, GreaterEqual,
+    ILike, In, Is, IsDistinct, IsNot, IsNotDistinct, Less, LessEqual, Like,
+    LShift, Mod, Mul, Neg, Not, NotBetween, NotEqual, NotILike, NotIn, NotLike,
+    Or, Pos, Pow, RShift, Sub)
 
 
 class TestOperators(unittest.TestCase):
@@ -312,8 +287,33 @@ class TestOperators(unittest.TestCase):
                 self.table.c1.like('foo'),
                 ~NotLike(self.table.c1, 'foo'),
                 ~~Like(self.table.c1, 'foo')]:
+            self.assertEqual(str(like), '("c1" LIKE %s ESCAPE %s)')
+            self.assertEqual(like.params, ('foo', '\\'))
+
+    def test_like_escape(self):
+        like = Like(self.table.c1, 'foo', escape='$')
+        self.assertEqual(str(like), '("c1" LIKE %s ESCAPE %s)')
+        self.assertEqual(like.params, ('foo', '$'))
+
+    def test_like_escape_empty_false(self):
+        flavor = Flavor(escape_empty=False)
+        Flavor.set(flavor)
+        try:
+            like = Like(self.table.c1, 'foo', escape='')
             self.assertEqual(str(like), '("c1" LIKE %s)')
             self.assertEqual(like.params, ('foo',))
+        finally:
+            Flavor.set(Flavor())
+
+    def test_like_escape_empty_true(self):
+        flavor = Flavor(escape_empty=True)
+        Flavor.set(flavor)
+        try:
+            like = Like(self.table.c1, 'foo', escape='')
+            self.assertEqual(str(like), '("c1" LIKE %s ESCAPE %s)')
+            self.assertEqual(like.params, ('foo', ''))
+        finally:
+            Flavor.set(Flavor())
 
     def test_ilike(self):
         flavor = Flavor(ilike=True)
@@ -322,8 +322,8 @@ class TestOperators(unittest.TestCase):
             for like in [ILike(self.table.c1, 'foo'),
                     self.table.c1.ilike('foo'),
                     ~NotILike(self.table.c1, 'foo')]:
-                self.assertEqual(str(like), '("c1" ILIKE %s)')
-                self.assertEqual(like.params, ('foo',))
+                self.assertEqual(str(like), '("c1" ILIKE %s ESCAPE %s)')
+                self.assertEqual(like.params, ('foo', '\\'))
         finally:
             Flavor.set(Flavor())
 
@@ -331,8 +331,9 @@ class TestOperators(unittest.TestCase):
         Flavor.set(flavor)
         try:
             like = ILike(self.table.c1, 'foo')
-            self.assertEqual(str(like), '(UPPER("c1") LIKE UPPER(%s))')
-            self.assertEqual(like.params, ('foo',))
+            self.assertEqual(
+                str(like), '(UPPER("c1") LIKE UPPER(%s) ESCAPE %s)')
+            self.assertEqual(like.params, ('foo', '\\'))
         finally:
             Flavor.set(Flavor())
 
@@ -342,8 +343,8 @@ class TestOperators(unittest.TestCase):
         try:
             for like in [NotILike(self.table.c1, 'foo'),
                     ~self.table.c1.ilike('foo')]:
-                self.assertEqual(str(like), '("c1" NOT ILIKE %s)')
-                self.assertEqual(like.params, ('foo',))
+                self.assertEqual(str(like), '("c1" NOT ILIKE %s ESCAPE %s)')
+                self.assertEqual(like.params, ('foo', '\\'))
         finally:
             Flavor.set(Flavor())
 
@@ -351,8 +352,9 @@ class TestOperators(unittest.TestCase):
         Flavor.set(flavor)
         try:
             like = NotILike(self.table.c1, 'foo')
-            self.assertEqual(str(like), '(UPPER("c1") NOT LIKE UPPER(%s))')
-            self.assertEqual(like.params, ('foo',))
+            self.assertEqual(
+                str(like), '(UPPER("c1") NOT LIKE UPPER(%s) ESCAPE %s)')
+            self.assertEqual(like.params, ('foo', '\\'))
         finally:
             Flavor.set(Flavor())
 
@@ -375,7 +377,7 @@ class TestOperators(unittest.TestCase):
             'UNION SELECT "a"."c3" FROM "t2" AS "a"))')
         self.assertEqual(in_.params, ())
 
-        in_ = In(self.table.c1, array('l', range(10)))
+        in_ = In(self.table.c1, array('l', list(range(10))))
         self.assertEqual(str(in_),
             '("c1" IN (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s))')
         self.assertEqual(in_.params, tuple(range(10)))
